Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Web
Imports System.Web.SessionState
Imports System.Web.UI
Imports System.Web.UI.WebControls
Imports System.Web.UI.HtmlControls
Imports Telerik.Web.UI

Namespace Telerik.Web.Examples.Dock.DynamicDocks
	Public Partial Class DefaultVB
		Inherits System.Web.UI.Page
		Private Property CurrentDockStates() As List(Of DockState)
			Get
				'Store the info about the added docks in the session. For real life
				' applications we recommend using database or other storage medium 
				' for persisting this information.
				Dim _currentDockStates As List(Of DockState) = DirectCast(Session("CurrentDockStatesDynamicDocks"), List(Of DockState))
				If [Object].Equals(_currentDockStates, Nothing) Then
					_currentDockStates = New List(Of DockState)()
					Session("CurrentDockStatesDynamicDocks") = _currentDockStates
				End If
				Return _currentDockStates
			End Get
			Set
				Session("CurrentDockStatesDynamicDocks") = value
			End Set
		End Property

		Private Function CreateRadDockFromState(state As DockState) As RadDock
			Dim dock As New RadDock()
			dock.DockMode = DockMode.Docked
			dock.ID = String.Format("RadDock{0}", state.UniqueName)
			dock.ApplyState(state)
			dock.Commands.Add(New DockCloseCommand())
			dock.Commands.Add(New DockExpandCollapseCommand())

			Return dock
		End Function

		Private Function CreateRadDock() As RadDock
			Dim docksCount As Integer = CurrentDockStates.Count

			Dim dock As New RadDock()
			dock.DockMode = DockMode.Docked
			dock.UniqueName = Guid.NewGuid().ToString().Replace("-", "a")
			dock.ID = String.Format("RadDock{0}", dock.UniqueName)
			dock.Title = "Dock"
			dock.Text = String.Format("Added at {0}", DateTime.Now)
			dock.Width = Unit.Pixel(300)

			dock.Commands.Add(New DockCloseCommand())
			dock.Commands.Add(New DockExpandCollapseCommand())

			Return dock
		End Function

		Private Sub CreateSaveStateTrigger(dock As RadDock)
			'Ensure that the RadDock control will initiate postback
			' when its position changes on the client or any of the commands is clicked.
			'Using the trigger we will "ajaxify" that postback.
			dock.AutoPostBack = True
			dock.CommandsAutoPostBack = True

			Dim saveStateTrigger As New AsyncPostBackTrigger()
			saveStateTrigger.ControlID = dock.ID
			saveStateTrigger.EventName = "DockPositionChanged"
			UpdatePanel1.Triggers.Add(saveStateTrigger)

			saveStateTrigger = New AsyncPostBackTrigger()
			saveStateTrigger.ControlID = dock.ID
			saveStateTrigger.EventName = "Command"
			UpdatePanel1.Triggers.Add(saveStateTrigger)
		End Sub

		Protected Sub Page_Init(sender As Object, e As EventArgs)
			'Recreate the docks in order to ensure their proper operation
			Dim i As Integer = 0
			While i < CurrentDockStates.Count
				Dim dock As RadDock = CreateRadDockFromState(CurrentDockStates(i))
				'We will just add the RadDock control to the RadDockLayout.
				' You could use any other control for that purpose, just ensure
				' that it is inside the RadDockLayout control.
				' The RadDockLayout control will automatically move the RadDock
				' controls to their corresponding zone in the LoadDockLayout
				' event (see below).
				RadDockLayout1.Controls.Add(dock)
				'We want to save the dock state every time a dock is moved.
				CreateSaveStateTrigger(dock)
				System.Math.Max(System.Threading.Interlocked.Increment(i),i - 1)
			End While
		End Sub

		Protected Sub RadDockLayout1_LoadDockLayout(sender As Object, e As DockLayoutEventArgs)
			'Populate the event args with the state information. The RadDockLayout control
			' will automatically move the docks according that information.
			For Each state As DockState In CurrentDockStates
				e.Positions(state.UniqueName) = state.DockZoneID
				e.Indices(state.UniqueName) = state.Index
			Next
		End Sub

		Protected Sub RadDockLayout1_SaveDockLayout(sender As Object, e As DockLayoutEventArgs)
			'Save the dock state in the page Session. This will enable us 
			' to recreate the dock in the next Page_Init. 
			CurrentDockStates = RadDockLayout1.GetRegisteredDocksState()
		End Sub

		Protected Sub ButtonAddDock_Click(sender As Object, e As EventArgs)
			Dim dock As RadDock = CreateRadDock()
			RadDockZone1.Controls.Add(dock)
			CreateSaveStateTrigger(dock)
		End Sub
	End Class
End Namespace
