Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Web
Imports System.Web.SessionState
Imports System.Web.UI
Imports System.Web.UI.WebControls
Imports System.Web.UI.HtmlControls
Imports Telerik.Web.UI

Namespace Telerik.Web.Examples.Dock.MyPortal
	Public Partial Class DefaultVB
		Inherits System.Web.UI.Page
		Private _dockStateCleared As Boolean = False
		Private Property CurrentDockStates() As List(Of DockState)
			Get
				'Store the info about the added docks in the session. For real life
				' applications we recommend using database or other storage medium 
				' for persisting this information.
				Dim _currentDockStates As List(Of DockState) = DirectCast(Session("CurrentDockStatesMyPortal"), List(Of DockState))
				If [Object].Equals(_currentDockStates, Nothing) Then
					_currentDockStates = New List(Of DockState)()
					Session("CurrentDockStatesMyPortal") = _currentDockStates
				End If
				Return _currentDockStates
			End Get
			Set
				Session("CurrentDockStatesMyPortal") = value
			End Set
		End Property

		Protected Sub Page_Load(sender As Object, e As EventArgs)
			If Not IsPostBack Then
				DropDownZone.DataBind()
			End If
		End Sub

		Public Function GetZones() As ArrayList
			Dim zones As New ArrayList()
			zones.Add(RadDockZone1)
			zones.Add(RadDockZone2)
			zones.Add(RadDockZone3)
			Return zones
		End Function

		Protected Sub Page_Init(sender As Object, e As EventArgs)
			'Recreate the docks in order to ensure their proper operation
			Dim i As Integer = 0
			While i < CurrentDockStates.Count
				If CurrentDockStates(i).Closed = False Then
					Dim dock As RadDock = CreateRadDockFromState(CurrentDockStates(i))
					'We will just add the RadDock control to the RadDockLayout.
					' You could use any other control for that purpose, just ensure
					' that it is inside the RadDockLayout control.
					' The RadDockLayout control will automatically move the RadDock
					' controls to their corresponding zone in the LoadDockLayout
					' event (see below).
					RadDockLayout1.Controls.Add(dock)
					'We want to save the dock state every time a dock is moved.
					CreateSaveStateTrigger(dock)
					'Load the selected widget
					LoadWidget(dock)
				End If
				System.Math.Max(System.Threading.Interlocked.Increment(i),i - 1)
			End While
		End Sub

		Protected Sub RadDockLayout1_LoadDockLayout(sender As Object, e As DockLayoutEventArgs)
			'Populate the event args with the state information. The RadDockLayout control
			' will automatically move the docks according that information.
			For Each state As DockState In CurrentDockStates
				e.Positions(state.UniqueName) = state.DockZoneID
				e.Indices(state.UniqueName) = state.Index
			Next
		End Sub

		Protected Sub RadDockLayout1_SaveDockLayout(sender As Object, e As DockLayoutEventArgs)
			If Not _dockStateCleared Then
				'Save the dock state in the session. This will enable us 
				' to recreate the dock in the next Page_Init.
				CurrentDockStates = RadDockLayout1.GetRegisteredDocksState()
			Else
				'the clear state button was clicked, so we refresh the page and start over.
				Response.Redirect(Request.RawUrl, False)
			End If
		End Sub

		Private Function CreateRadDockFromState(state As DockState) As RadDock
			Dim dock As New RadDock()
			dock.DockMode = DockMode.Docked
			dock.ID = String.Format("RadDock{0}", state.UniqueName)
			dock.ApplyState(state)
			dock.Commands.Add(New DockCloseCommand())
			dock.Commands.Add(New DockExpandCollapseCommand())

			Return dock
		End Function

		Private Function CreateRadDock() As RadDock
			Dim docksCount As Integer = CurrentDockStates.Count

			Dim dock As New RadDock()
			dock.DockMode = DockMode.Docked
			dock.UniqueName = Guid.NewGuid().ToString().Replace("-", "a")
			dock.ID = String.Format("RadDock{0}", dock.UniqueName)
			dock.Title = "Dock"
			dock.Text = String.Format("Added at {0}", DateTime.Now)
			dock.Width = Unit.Pixel(300)

			dock.Commands.Add(New DockCloseCommand())
			dock.Commands.Add(New DockExpandCollapseCommand())

			Return dock
		End Function

		Private Sub CreateSaveStateTrigger(dock As RadDock)
			'Ensure that the RadDock control will initiate postback
			' when its position changes on the client or any of the commands is clicked.
			'Using the trigger we will "ajaxify" that postback.
			dock.AutoPostBack = True
			dock.CommandsAutoPostBack = True

			Dim saveStateTrigger As New AsyncPostBackTrigger()
			saveStateTrigger.ControlID = dock.ID
			saveStateTrigger.EventName = "DockPositionChanged"
			UpdatePanel1.Triggers.Add(saveStateTrigger)

			saveStateTrigger = New AsyncPostBackTrigger()
			saveStateTrigger.ControlID = dock.ID
			saveStateTrigger.EventName = "Command"
			UpdatePanel1.Triggers.Add(saveStateTrigger)
		End Sub

		Private Sub LoadWidget(dock As RadDock)
			If String.IsNullOrEmpty(dock.Tag) Then
				Return
			End If
			Dim widget As Control = LoadControl(dock.Tag)
			dock.ContentContainer.Controls.Add(widget)
		End Sub


		Protected Sub ButtonAddDock_Click(sender As Object, e As EventArgs)
			Dim dock As RadDock = CreateRadDock()
			'find the target zone and add the new dock there
			Dim dz As RadDockZone = DirectCast(FindControl(DropDownZone.SelectedItem.Text), RadDockZone)
			dz.Controls.Add(dock)
			CreateSaveStateTrigger(dock)

			'Load the selected widget in the RadDock control
			dock.Tag = DroptDownWidget.SelectedValue
			LoadWidget(dock)
		End Sub
		Protected Sub ButtonPostBack_Click(sender As Object, e As EventArgs)
			'normal postback
		End Sub
		Protected Sub ButtonClear_Click(sender As Object, e As EventArgs)
			'clear docks state from the session
			CurrentDockStates.Clear()
			_dockStateCleared = True
		End Sub
	End Class
End Namespace
